<?php
/**
	* Creates proper tables for M2F
	*
	* @author Patricio Anguita
	* @license http://opensource.org/licenses/gpl-license.php GNU Public License
	* @version $Revision: 1.51 $
	* @internal $Id: m2f_schema.php,v 1.51 2006/07/18 23:42:32 georgeocrawford Exp $
*/

//
//
// Whenever the schema is changed in any way, be sure to increment the $m2f_desired_db_version
// value in m2f_common.php!!!!!
//
//
	
function m2f_create_tables($type_db, $m2f_desired_db_version)
{
	global $m2f_db;
	
	// Since the board configuration isn't available yet, read directly from the db
	$sql = "SELECT config_value
					FROM " . CONFIG_TABLE . "
					WHERE config_name = 'board_email'";
	$db_result = $m2f_db->GetOne($sql);
	check_db_result($db_result, $sql, __LINE__, __FILE__);
	$board_email = $db_result;
	
	// Default distribution list settings
	$m2f_distributionlist_settings = array(
		'_M2F_MAIL_BACKEND_' => 'mail',
		'_M2F_INPUT_BACKEND_' => 'pop3',
		'_M2F_SMTP_HOST_' => 'localhost',
		'_M2F_SMTP_PORT_' => '25',
		'_M2F_SMTP_AUTH_' => '0',
		'_M2F_SMTP_USERNAME_' => '',
		'_M2F_SMTP_PASSWORD_' => '',
		'_M2F_MBOX_FILE_' => '/path/to/mbox',
		'_M2F_POP3_HOST_' => 'pop.host.com',
		'_M2F_POP3_PORT_' => '110',
		'_M2F_POP3_USER_' => '',
		'_M2F_POP3_PASS_' => '',
		'_M2F_POP3_APOP_' => '1',
		'_M2F_MAX_MSG_RETRIEVE_' => '10',
		'_M2F_MAX_MESSAGE_SIZE_' => '0',
		'_M2F_EXTRACT_MAIL_DATES_' => '1',
		'_M2F_SHOW_GUEST_EMAIL_' => '1',
		'_M2F_IGNORE_TO_HEADER_' => '1',
		'_M2F_NO_REPLYTO_RECP_' => '1',
		'_M2F_DELETE_IMPORTED_MESSAGES_' => '1',
		'_M2F_EXTERNAL_LIST_SERVER_' => '0',
		'_M2F_REPLY_PREFIXES_' => array('Re:','Fw:','Rv:','Fwd:'),
		'_M2F_SUBJECT_PREFIX_' => '',
		'_M2F_FROM_FIELD_' => 'user_address',
		'_M2F_FROM_OTHER_ADDRESS_' => 'address@domain.com>',
		'_M2F_ALLOW_GUEST_POSTING_' => '0',
		'_M2F_FORCE_GUEST_POSTING_' => '0',
		'_M2F_IGNORE_SECURITY_SETTINGS_' => '0',
		'_M2F_DISALLOW_GUEST_ACTION_' => 'moderate',
		'_M2F_ADMIN_EMAIL_ADDRESS_' => '"Admin" <' . $board_email . '>',
		'_M2F_BOUNCE_INCLUDE_LINK_' => '0',
		'_M2F_RESEND_EDITED_POST_' => '0',
		'_M2F_ADD_SUBJECT_TAG_EDITED_POST_' => '[Edited]',
		'_M2F_ADD_BODY_TAG_EDITED_POST_' => "This is an edited version of a previous post\n\n",
		'_M2F_MODERATED_LIST_IN_' => '0',
		'_M2F_MODERATED_LIST_OUT_' => '0',
		'_M2F_MODERATOR_NOTIFY_' => 'none',
		'_M2F_MODERATOR_NOTIFY_EMAIL_' => '',
		'_M2F_MODERATOR_IGNORE_ADMIN_' => '0',
		'_M2F_ADD_AUTHOR_AS_RECIPIENT_' => '1',
	);

	$m2f_config_settings = array(
		'_M2F_SENDMAIL_PATH_' => '/usr/sbin/sendmail',
		'_M2F_SENDMAIL_ARGS_' => '-i',
		'_M2F_FORUM_POST_SIGNATURE_' => 'Post generated using Mail2Forum (http://www.mail2forum.com)',
		'_M2F_MAIL_MSG_SIGNATURE_' => "Sent using Mail2Forum (http://www.mail2forum.com). \n\nRead this topic online here:",
		'_M2F_ANON_USERID_' => '-1',
		'_M2F_BLANK_SUBJECT_TEXT_' => 'No Title',
		'_M2F_SUBJECT_REPLY_PREFIX_' => 'Re: ',
		'_M2F_FORCE_SUBJECT_MATCH_' => '1',
		'_M2F_ENABLE_ATTACHMENTS_' => '0',
		'_M2F_CRON_PROBABILITY_' => '1',
		'_M2F_LOG_PRUNE_' => '30',
		'_M2F_HASH_PRUNE_' => '30',
		'_M2F_CRON_DELAY_' => '5',
		'_M2F_SIGNATURE_SEPARATOR_' => '-------------------- m2f --------------------',
		'_M2F_INCLUDE_SIGNATURE_LINK_' => '1',
		'_M2F_DEFAULT_EMAIL_PREFS_' => '21',
		'_M2F_DB_VERSION_' => $m2f_desired_db_version,
	);
	
	
	// Try to build the DB schema
	switch ($type_db)
	{
		case 'mysql':
			m2f_create_tables_mysql($m2f_desired_db_version, $m2f_distributionlist_settings, $m2f_config_settings);
			break;
		case 'pgsql':
			m2f_create_tables_pgsql($m2f_desired_db_version, $m2f_distributionlist_settings, $m2f_config_settings);
			break;
		default:
			m2f_log(PEAR_LOG_CRIT , "Could not find the database schema file in {$_GLOBALS['m2f_root_path']}/db/m2f_schema_$type_db.php" , __LINE__ , __FILE__ );
			die;
			break;
	}
	m2f_log(PEAR_LOG_NOTICE , "M2F tables created" , __LINE__ , __FILE__ );

}
?>