<?php
/**
  * Update m2f database schema to version 4
  *
  * @author Patricio Anguita
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
  * @version
  * @internal
*/



function m2f_update_schema_4($type_db)
{
	global $m2f_db;

	// Set up default config values
	$m2f_config_settings = array(
		'_M2F_TRACKING_HEADER_' => 'References',
		'_M2F_SENDMAIL_PATH_' => '/usr/bin/sendmail',
		'_M2F_SENDMAIL_ARGS_' => '-i',
		'_M2F_FORUM_POST_SIGNATURE_' => 'Post generated using Mail2Forum (http://www.mail2forum.com)',
		'_M2F_MAIL_MSG_SIGNATURE_' => 'Sent using Mail2Forum (http://www.mail2forum.com)\n\nRead this topic online here: <<topic_link>>',
		'_M2F_MAX_MSG_RETRIEVE_' => '10',
		'_M2F_ANON_USERID_' => '-1',
		'_M2F_BLANK_SUBJECT_TEXT_' => 'No Title',
		'_M2F_FORCE_SUBJECT_MATCH_' => '1',
		'_M2F_SEND_HTML_' => '1',
		'_M2F_RECONSTITUTE_HTML_MSGS_' => '1',
		'_M2F_DB_VERSION_' => '4'
	);
		
	// Default distribution list settings
	$m2f_distributionlist_settings = array(
		'_M2F_MAIL_BACKEND_' => 'mail',
		'_M2F_INPUT_BACKEND_' => 'pop3',
		'_M2F_SMTP_HOST_' => 'localhost',
		'_M2F_SMTP_PORT_' => '25',
		'_M2F_SMTP_AUTH_' => '0',
		'_M2F_SMTP_USERNAME_' => '',
		'_M2F_SMTP_PASSWORD_' => '',
		'_M2F_MBOX_FILE_' => '/path/to/mbox',
		'_M2F_POP3_HOST_' => 'pop.host.com',
		'_M2F_POP3_PORT_' => '110',
		'_M2F_POP3_USER_' => '',
		'_M2F_POP3_PASS_' => '',
		'_M2F_EXTRACT_MAIL_DATES_' => '1',
		'_M2F_SHOW_GUEST_EMAIL_' => '1',
		'_M2F_IGNORE_TO_HEADER_' => '1',
		'_M2F_USE_ALL_ADDRESSES_' => '0',
		'_M2F_RESEND_INCOMING_MAIL_' => '1',
		'_M2F_REMOVE_SUBJECT_WORDS_' => '[M2F]',
		'_M2F_REPLY_PREFIXES_' => array('Re:','Fw:','Rv:'),
		'_M2F_FROM_FIELD_' => 'user_address',
		'_M2F_FROM_OTHER_ADDRESS_' => '"Full Name" <address@domain.com>',
		'_M2F_ALLOW_GUEST_POSTING_' => '0',
		'_M2F_DISALLOW_GUEST_ACTION_' => 'bounce_and_admin',
		'_M2F_ADMIN_EMAIL_ADDRESS_' => '', // See code in m2f_update_distributionlists
		'_M2F_BOUNCE_INCLUDE_LINK_' => '0'
	);
	
	//
	// Update the DB tables from a previous version of M2F
	//
	
	// Change table m2f_config, column config_value to type "text"
	$sql = "DESCRIBE " . _M2F_CONFIG_TABLE_ . " config_value";
	$db_result = $m2f_db->getRow($sql);
	check_db_result($db_result, $sql, __LINE__, __FILE__);
	
	if ($db_result['Type'] != 'text')
	{
		// Remove the primary key, as it really isn't needed for such a small table
		$sql = "ALTER TABLE " . _M2F_CONFIG_TABLE_ . " DROP PRIMARY KEY";
		$db_result = $m2f_db->query($sql);
		check_db_result($db_result, $sql, __LINE__, __FILE__);

		// Changing a column type seems to be DB-dependent
		if ($type_db == 'mysql')
		{
			// Modify the type of the config_value column so it can hold arbitrarily large values
			$sql = "ALTER TABLE " . _M2F_CONFIG_TABLE_ . " MODIFY config_value TEXT";
			$db_result = $m2f_db->query($sql);
			check_db_result($db_result, $sql, __LINE__, __FILE__);
	
		}
		elseif ($type_db == 'pgsql')
		{
			// Rename the old config_value column
			$sql = "ALTER TABLE " . _M2F_CONFIG_TABLE_ . "
							RENAME config_value TO config_value_old";
			$db_result = $m2f_db->query($sql);
			check_db_result($db_result, $sql, __LINE__, __FILE__);
			
			// Create the new config_value column
			$sql = "ALTER TABLE " . _M2F_CONFIG_TABLE_ . "
							ADD config_value text";
			$db_result = $m2f_db->query($sql);
			check_db_result($db_result, $sql, __LINE__, __FILE__);

			// Copy over the config_value data
			$sql = "UPDATE " . _M2F_CONFIG_TABLE_ . "
							SET config_value = config_value_old";
			$db_result = $m2f_db->query($sql);
			check_db_result($db_result, $sql, __LINE__, __FILE__);

			// Drop the old config_value column
			$sql = "ALTER TABLE " . _M2F_CONFIG_TABLE_ . "
							DROP config_value_old";
			$db_result = $m2f_db->query($sql);
			check_db_result($db_result, $sql, __LINE__, __FILE__);
		}
	}
	
	// Change table m2f_subscription, column list_email to user_id
	$sql = "DESCRIBE " . _M2F_SUBSCRIPTION_TABLE_ . " user_id";
	$db_result = $m2f_db->getRow($sql);
	check_db_result($db_result, $sql, __LINE__, __FILE__);
	
	if ($db_result == '')
	{
		// Remove the primary key so it doesn't get in the way
		$sql = "ALTER TABLE " . _M2F_SUBSCRIPTION_TABLE_ . " DROP PRIMARY KEY";
		$db_result = $m2f_db->query($sql);
		check_db_result($db_result, $sql, __LINE__, __FILE__);
		
		// Warn administrator about subscribed emails that have no associated user
		$sql = "SELECT s.*
						FROM " . _M2F_SUBSCRIPTION_TABLE_ . " s
         			LEFT JOIN " . USERS_TABLE . " u
         			ON s.email = u.user_email
         		WHERE u.user_email IS NULL";
		$db_result = $m2f_db->getAll($sql);
		check_db_result($db_result, $sql, __LINE__, __FILE__);
		
		foreach ($db_result as $row)
		{
			$msg = "Removed from subscription table (mailinglist_id, email): {$row['mailinglist_id']}, {$row['list_email']}";
			m2f_log(PEAR_LOG_WARNING , $msg , __LINE__ , __FILE__ );
		}

		// Delete the unassociated email addresses, otherwise they will have user_id = 0
		// after conversion
		$sql = "DELETE " . _M2F_SUBSCRIPTION_TABLE_ . ".*
						FROM " . _M2F_SUBSCRIPTION_TABLE_ . " s
         			LEFT JOIN " . USERS_TABLE . " u
         			ON s.email = u.user_email
         		WHERE u.user_email IS NULL";
		$db_result = $m2f_db->query($sql);
		check_db_result($db_result, $sql, __LINE__, __FILE__);

		// Add the new user_id column
		$sql = "ALTER TABLE " . _M2F_SUBSCRIPTION_TABLE_ . "
						ADD COLUMN user_id INTEGER default '0'";
		$db_result = $m2f_db->query($sql);
		check_db_result($db_result, $sql, __LINE__, __FILE__);
		
		// Populate the new user_id column by looking up the email in the user table
		$sql = "UPDATE " . _M2F_SUBSCRIPTION_TABLE_ . " s, " . USERS_TABLE . " u
						SET s.user_id = u.user_id
						WHERE s.email = u.user_email"; 
		$db_result = $m2f_db->query($sql);
		check_db_result($db_result, $sql, __LINE__, __FILE__);

		// Drop the old email column
		$sql = "ALTER TABLE " . _M2F_SUBSCRIPTION_TABLE_ . " DROP COLUMN email";
		$db_result = $m2f_db->query($sql);
		check_db_result($db_result, $sql, __LINE__, __FILE__);

		// Add the primary key
		$sql = "ALTER TABLE " . _M2F_SUBSCRIPTION_TABLE_ . " ADD PRIMARY KEY (mailinglist_id, user_id)";
		$db_result = $m2f_db->query($sql);
		check_db_result($db_result, $sql, __LINE__, __FILE__);
	}

  $sql = "SELECT config_name, config_value FROM " . _M2F_CONFIG_TABLE_;
  $current_config =& $m2f_db->getAssoc($sql, false, array(), DB_FETCHMODE_DEFAULT, true);
	check_db_result($db_result, $sql, __LINE__, __FILE__);

	// Add config values that are missing
	foreach ($m2f_config_settings as $config_name => $config_value)
	{
		if (!isset($current_config[$config_name]))
		{
			$sql = "INSERT INTO " . _M2F_CONFIG_TABLE_ . "
								(config_name, config_value)
							VALUES ('$config_name', '$config_value')";
			$db_result = $m2f_db->query($sql);
			check_db_result($db_result, $sql, __LINE__, __FILE__);
		}
	}
	
	//
	// Adds any missing distribution list settings to the table
	//

	// Get list of current distribution lists
	$sql = "SELECT distributionlist_id FROM " . _M2F_DISTRIBUTIONLIST_TABLE_;
	$db_result = $m2f_db->getCol($sql);
	check_db_result($db_result, $sql, __LINE__, __FILE__);
	
	$ids = $db_result;
	foreach ($ids as $id)
	{
		$sql = "SELECT config_name, config_value
						FROM " . _M2F_DISTRIBUTIONLIST_CONFIG_TABLE_ . "
						WHERE distributionlist_id = $id";
		$db_result = $m2f_db->getAssoc($sql);
		check_db_result($db_result, $sql, __LINE__, __FILE__);

		$existing_configs = $db_result;
		foreach ($m2f_distributionlist_settings as $key => $value)
		{
			if (!isset($existing_configs[$key]))
			{
				if ($key == '_M2F_ADMIN_EMAIL_ADDRESS_')
				{
					// Since the board configuration isn't available yet, read directly from the db
					$sql = "SELECT config_value
									FROM " . CONFIG_TABLE . "
									WHERE config_name = 'board_email'";
					$db_result = $m2f_db->GetOne($sql);
					check_db_result($db_result, $sql, __LINE__, __FILE__);
					$value = $db_result;
				}
				if (is_array($value))
				{
					foreach ($value as $subvalue)
					{
						$sql = "INSERT INTO " . _M2F_DISTRIBUTIONLIST_CONFIG_TABLE_ . "
											(distributionlist_id, config_name, config_value)
										VALUES ('$id', '$key', '$subvalue')";
						$db_result = $m2f_db->query($sql);
						check_db_result($db_result, $sql, __LINE__, __FILE__);
					}
				}
				else
				{
					$sql = "INSERT INTO " . _M2F_DISTRIBUTIONLIST_CONFIG_TABLE_ . "
										(distributionlist_id, config_name, config_value)
									VALUES ('$id', '$key', '$value')" ;
					$db_result = $m2f_db->query($sql);
					check_db_result($db_result, $sql, __LINE__, __FILE__);
				}
			}
		}
	} 
	
	
	// Update version number
	$sql = "UPDATE " . _M2F_CONFIG_TABLE_ . "
	     		SET config_value = 4
	     		WHERE config_name = '_M2F_DB_VERSION_'";
	$db_result = $m2f_db->query($sql);
	check_db_result($db_result, $sql, __LINE__, __FILE__);
	m2f_log(PEAR_LOG_NOTICE , "Updated DB version to 4" , __LINE__ , __FILE__ );
	
	return TRUE;
}

?>