<?php
/**
  * Update m2f database schema to version 8
  *
  * @author Patricio Anguita
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
  * @version
  * @internal
*/



function m2f_update_schema_8($type_db)
{
	global $m2f_db;

	// Set up default config values
	$m2f_config_settings = array(
		'_M2F_SENDMAIL_PATH_' => '/usr/bin/sendmail',
		'_M2F_SENDMAIL_ARGS_' => '-i',
		'_M2F_FORUM_POST_SIGNATURE_' => 'Post generated using Mail2Forum (http://www.mail2forum.com)',
		'_M2F_MAIL_MSG_SIGNATURE_' => "Sent using Mail2Forum (http://www.mail2forum.com). \n\nRead this topic online here:",
		'_M2F_ANON_USERID_' => '-1',
		'_M2F_BLANK_SUBJECT_TEXT_' => 'No Title',
		'_M2F_SUBJECT_REPLY_PREFIX_' => 'Re: ',
		'_M2F_FORCE_SUBJECT_MATCH_' => '1',
		'_M2F_SEND_HTML_' => '1',
		'_M2F_RECONSTITUTE_HTML_MSGS_' => '1',
		'_M2F_SEND_ATTACHMENT_LINK_' => '1',
		'_M2F_ENABLE_ATTACHMENTS_' => '0',
		'_M2F_CRON_PROBABILITY_' => '1',
		'_M2F_CRON_DELAY_' => '5',
		'_M2F_SIGNATURE_SEPARATOR_' => '-------------------- m2f --------------------',
		'_M2F_INCLUDE_SIGNATURE_LINK_' => '1',
		'_M2F_DB_VERSION_' => '8'
	);

	// Since the board configuration isn't available yet, read directly from the db
	$sql = "SELECT config_value
					FROM " . CONFIG_TABLE . "
					WHERE config_name = 'board_email'";
	$db_result = $m2f_db->GetOne($sql);
	check_db_result($db_result, $sql, __LINE__, __FILE__);
	$board_email = $db_result;

	// Default distribution list settings
	$m2f_distributionlist_settings = array(
		'_M2F_MAIL_BACKEND_' => 'mail',
		'_M2F_INPUT_BACKEND_' => 'pop3',
		'_M2F_SMTP_HOST_' => 'localhost',
		'_M2F_SMTP_PORT_' => '25',
		'_M2F_SMTP_AUTH_' => '0',
		'_M2F_SMTP_USERNAME_' => '',
		'_M2F_SMTP_PASSWORD_' => '',
		'_M2F_MBOX_FILE_' => '/path/to/mbox',
		'_M2F_POP3_HOST_' => 'pop.host.com',
		'_M2F_POP3_PORT_' => '110',
		'_M2F_POP3_USER_' => '',
		'_M2F_POP3_PASS_' => '',
		'_M2F_POP3_APOP_' => '1',
		'_M2F_MAX_MSG_RETRIEVE_' => '10',
		'_M2F_EXTRACT_MAIL_DATES_' => '1',
		'_M2F_SHOW_GUEST_EMAIL_' => '1',
		'_M2F_IGNORE_TO_HEADER_' => '1',
		'_M2F_NO_REPLYTO_RECP_' => '1',
		'_M2F_USE_ALL_ADDRESSES_' => '1',
		'_M2F_DELETE_IMPORTED_MESSAGES_' => '1',
		'_M2F_EXTERNAL_LIST_SERVER_' => '0',
		'_M2F_REPLY_PREFIXES_' => array('Re:','Fw:','Rv:'),
		'_M2F_SUBJECT_PREFIX_' => '',
		'_M2F_FROM_FIELD_' => 'user_address',
		'_M2F_FROM_OTHER_ADDRESS_' => '"Full Name" <address@domain.com>',
		'_M2F_ALLOW_GUEST_POSTING_' => '0',
		'_M2F_DISALLOW_GUEST_ACTION_' => 'bounce_and_admin',
		'_M2F_ADMIN_EMAIL_ADDRESS_' => $board_email,
		'_M2F_BOUNCE_INCLUDE_LINK_' => '0',
		'_M2F_RESEND_EDITED_POST_' => '0',
		'_M2F_ADD_SUBJECT_TAG_EDITED_POST_' => '[Edited]',
		'_M2F_ADD_BODY_TAG_EDITED_POST_' => "This is an edited version of a previous post\n\n"
	);


	//
	// Update the DB tables from a previous version of M2F
	//
	
  // get existing tables
  $sql = 'SHOW TABLES';
  $existing_tables = $m2f_db->getCol($sql);
  
	// add the new tables if any are missing
	if (!in_array(_M2F_CRON_TABLE_, $existing_tables)) 
	{
		$sql = "CREATE TABLE " . _M2F_CRON_TABLE_ . "
						(
							cron_id int(11) NOT NULL auto_increment,
							`timestamp` varchar(32) NOT NULL default '',
							`results` text NOT NULL,
							`status` tinyint(4) NOT NULL default '0',
							PRIMARY KEY  (cron_id)
						)";
		$db_result = $m2f_db->query($sql);
		check_db_result($db_result, $sql, __LINE__, __FILE__);
	}
	
	if (!in_array(_M2F_MESSAGE_ID_TABLE_, $existing_tables)) 
	{
		$sql = "CREATE TABLE " . _M2F_MESSAGE_ID_TABLE_ . "
						(
							`post_id` mediumint(8) NOT NULL default '0',
							`message_id` varchar(255) NOT NULL default '',
							PRIMARY KEY  (`message_id`)
						)";
		$db_result = $m2f_db->query($sql);
		check_db_result($db_result, $sql, __LINE__, __FILE__);
	}
		
	if (!in_array(_M2F_MESSAGE_HASH_TABLE_, $existing_tables)) 
	{
		$sql = "CREATE TABLE " . _M2F_MESSAGE_HASH_TABLE_ . "
						(
							`hash` varchar(255) NOT NULL default '',
							PRIMARY KEY  (`hash`)
						)";
		$db_result = $m2f_db->query($sql);
		check_db_result($db_result, $sql, __LINE__, __FILE__);
	}
	
	if (!in_array(_M2F_GROUP_SUBSCRIPTION_TABLE_, $existing_tables)) 
	{
		$sql = "CREATE TABLE " . _M2F_GROUP_SUBSCRIPTION_TABLE_ . "
						(
							mailinglist_id INTEGER NOT NULL default '0',
							group_id INTEGER NOT NULL default '0',
							PRIMARY KEY (mailinglist_id, group_id)
						)";
		$db_result = $m2f_db->query($sql);
		check_db_result($db_result, $sql, __LINE__, __FILE__);
	}
	
	if (!in_array(_M2F_LOG_TABLE_, $existing_tables)) 
	{
		$sql = "CREATE TABLE " . _M2F_LOG_TABLE_ . "
						(
							id int(11) NOT NULL default '0', 
							logtime timestamp(14) default '0', 
							ident varchar(16) default '', 
							priority int(11) default '0', 
							message text, 
							PRIMARY KEY (id) 
						)"; 
		$db_result = $m2f_db->query($sql);
		check_db_result($db_result, $sql, __LINE__, __FILE__);
	}
	
	if (!in_array(_M2F_PATTERN_MATCH_TABLE_, $existing_tables)) 
	{
		$sql = "CREATE TABLE " . _M2F_PATTERN_MATCH_TABLE_ . " 
						(
							`pattern_id` int(11) NOT NULL auto_increment,
							`pattern_match` text,
							`pattern_replace` text,
							`regexp` tinyint(1) NOT NULL default '0',
							`modifiers` varchar(10) default NULL,
							`description` text,
							`target` varchar(20) default NULL,
							`internal` tinyint(1) NOT NULL default '0',
							PRIMARY KEY  (`pattern_id`)
						)";
		$db_result = $m2f_db->query($sql);
		check_db_result($db_result, $sql, __LINE__, __FILE__);
	}
	
	if (!in_array(_M2F_DIST_LIST_PATTERNS_TABLE_, $existing_tables)) 
	{
		$sql = "CREATE TABLE " . _M2F_DIST_LIST_PATTERNS_TABLE_ . "
						(
							`distributionlist_id` int(11) NOT NULL default '0',
							`pattern_id` int(11) NOT NULL default '0',
							`order` int(11) NOT NULL default '0',
							PRIMARY KEY  (`distributionlist_id`,`pattern_id`,`order`)
						)";
		$db_result = $m2f_db->query($sql);
		check_db_result($db_result, $sql, __LINE__, __FILE__);
	}

	// this is left till now because the Log table may well not exist beforehand!
 	m2f_log(PEAR_LOG_NOTICE , "Updating M2F tables to DB version 8" , __LINE__ , __FILE__);
 	m2f_log(PEAR_LOG_NOTICE , "Added new tables" , __LINE__ , __FILE__);


	// Add config values that are missing

  $sql = "SELECT config_name, config_value FROM " . _M2F_CONFIG_TABLE_;
  $current_config =& $m2f_db->getAssoc($sql, false, array(), DB_FETCHMODE_DEFAULT, true);
	check_db_result($db_result, $sql, __LINE__, __FILE__);

	foreach ($m2f_config_settings as $config_name => $config_value)
	{
		if (!isset($current_config[$config_name]))
		{
			$sql = "INSERT INTO " . _M2F_CONFIG_TABLE_ . "
								(config_name, config_value)
							VALUES ('$config_name', '$config_value')";
			$db_result = $m2f_db->query($sql);
			check_db_result($db_result, $sql, __LINE__, __FILE__);
		}
	}
	
	// Remove old config values
	foreach ($current_config as $key => $value)
	{
		if ($key == '_M2F_TRACKING_HEADER_')
		{
			$sql = "DELETE FROM " . _M2F_CONFIG_TABLE_ . "
								WHERE config_name = '_M2F_RESEND_INCOMING_MAIL_'";
			$db_result = $m2f_db->query($sql);
			check_db_result($db_result, $sql, __LINE__, __FILE__);
		}
		if ($key == '_M2F_MAX_MSG_RETRIEVE_')
		{
			$sql = "DELETE FROM " . _M2F_CONFIG_TABLE_ . "
								WHERE config_name = '_M2F_MAX_MSG_RETRIEVE_'";
			$db_result = $m2f_db->query($sql);
			check_db_result($db_result, $sql, __LINE__, __FILE__);
		}
	}
	
 	m2f_log(PEAR_LOG_NOTICE , "Updated m2f config table" , __LINE__ , __FILE__);


	//
	// Adds any missing distribution list settings to the table
	//
	
	// Get list of current distribution lists
	$sql = "SELECT distributionlist_id FROM " . _M2F_DISTRIBUTIONLIST_TABLE_;
	$db_result = $m2f_db->getCol($sql);
	check_db_result($db_result, $sql, __LINE__, __FILE__);
	
	$ids = $db_result;
	foreach ($ids as $id)
	{
		$sql = "SELECT config_name, config_value
						FROM " . _M2F_DISTRIBUTIONLIST_CONFIG_TABLE_ . "
						WHERE distributionlist_id = $id";
		$db_result =& $m2f_db->getAssoc($sql, false, array(), DB_FETCHMODE_DEFAULT, true);
		check_db_result($db_result, $sql, __LINE__, __FILE__);

		$existing_configs = $db_result;
		
		// add missing config values
		foreach ($m2f_distributionlist_settings as $key => $value)
		{
			if (!isset($existing_configs[$key]))
			{
				if (is_array($value))
				{
					foreach ($value as $subvalue)
					{
						$sql = "INSERT INTO " . _M2F_DISTRIBUTIONLIST_CONFIG_TABLE_ . "
											(distributionlist_id, config_name, config_value)
										VALUES ('$id', '$key', '$subvalue')";
						$db_result = $m2f_db->query($sql);
						check_db_result($db_result, $sql, __LINE__, __FILE__);
					}
				}
				else
				{
					$sql = "INSERT INTO " . _M2F_DISTRIBUTIONLIST_CONFIG_TABLE_ . "
										(distributionlist_id, config_name, config_value)
									VALUES ('$id', '$key', '$value')" ;
					$db_result = $m2f_db->query($sql);
					check_db_result($db_result, $sql, __LINE__, __FILE__);
				}
				
			}
		}

		// remove deleted values
		foreach ($existing_configs as $key => $value)
		{
			if ($key == '_M2F_RESEND_INCOMING_MAIL_')
			{
				$sql = "DELETE FROM " . _M2F_DISTRIBUTIONLIST_CONFIG_TABLE_ . "
									WHERE config_name = '_M2F_RESEND_INCOMING_MAIL_'
									AND distributionlist_id = '$id'";
				$db_result = $m2f_db->query($sql);
				check_db_result($db_result, $sql, __LINE__, __FILE__);
			}
			if ($key == '_M2F_REMOVE_SUBJECT_WORDS_')
			{
				foreach ($value as $search)	$copied_regexp_patterns[] = array('dist_list' => $id, 'search' => $search);
			}
		}
		
		if (!empty($copied_regexp_patterns))
		{
			$sql = "DELETE FROM " . _M2F_DISTRIBUTIONLIST_CONFIG_TABLE_ . "
								WHERE config_name = '_M2F_REMOVE_SUBJECT_WORDS_'
								AND distributionlist_id = '$id'";
			$db_result = $m2f_db->query($sql);
			check_db_result($db_result, $sql, __LINE__, __FILE__);
		}
	}    
	
 	m2f_log(PEAR_LOG_NOTICE , "Updated distribution list settings" , __LINE__ , __FILE__);

	// check to see if default dist list needs to be set up
	$sql = "select * from " . _M2F_DISTRIBUTIONLIST_CONFIG_TABLE_ . " where distributionlist_id = 0";
	$db_result = $m2f_db->getOne($sql);
	
	if (empty($db_result))
	{
		// Set up default distributionlist configuration table
		foreach ($m2f_distributionlist_settings as $k => $v)
		{
			if (is_array($v))
			{
				foreach ($v as $b)
				{
					$sql = "INSERT INTO " . _M2F_DISTRIBUTIONLIST_CONFIG_TABLE_ . "
										(distributionlist_id, config_name, config_value)
									VALUES ('0', '$k', '$b')";
					$db_result = $m2f_db->query($sql);
					check_db_result($db_result, $sql, __LINE__, __FILE__);
				}
			}
			else
			{
				$sql = "INSERT INTO " . _M2F_DISTRIBUTIONLIST_CONFIG_TABLE_ . "
									(distributionlist_id, config_name, config_value)
								VALUES ('0', '$k', '$v')" ;
				$db_result = $m2f_db->query($sql);
				check_db_result($db_result, $sql, __LINE__, __FILE__);
			}      
		}
		m2f_log(PEAR_LOG_NOTICE , "Added default distribution list" , __LINE__ , __FILE__);
	}


	//
	// Add hardcoded patterns
	//
	
	// insert hardcoded Yahoo Groups patterns
	$sql = 'INSERT INTO `' . _M2F_PATTERN_MATCH_TABLE_ . '` 
					(`pattern_match`,`pattern_replace`,`regexp`,`modifiers`,`description`,`target`,`internal`) 
					VALUES 
					("' . $m2f_db->escapeSimple('\s*<!-- [^>]+begin egp html banner.+end egp html banner[^>]+ -->\s*') . '","\n","1","s","*Yahoo Groups* Remove HTML-style Yahoo Groups footer in HTML body","Body","1"), 
					("' . $m2f_db->escapeSimple('\s*Yahoo! Groups Links.+http:\/\/docs\.yahoo\.com\/info\/terms\/\s*') . '","\n","1","s","*Yahoo Groups* Remove text-style Yahoo Groups footers in text body","Body","1"),
					("' . $m2f_db->escapeSimple('(?<=\W)[>\n\r -]+\*?Yahoo! Groups Sponsor.+(?=(?i)<\/body>)') . '","\n","1","sm","*Yahoo Groups* Remove text-style Yahoo Groups footer in HTML body","Body","1"),
					("' . $m2f_db->escapeSimple('(?<=\W)[>\n\r -]+\*?Yahoo! Groups Sponsor.+') . '","\n","1","sm","*Yahoo Groups* Remove text-style Yahoo Groups footer in text body","Body","1")';
	$db_result = $m2f_db->query($sql);
	check_db_result($db_result, $sql, __LINE__, __FILE__);
	
	if (!empty($copied_regexp_patterns))
	{
		foreach ($copied_regexp_patterns as $record)
		{
			$search = $record['search'];
			$dist_list = $record['dist_list'];
			$sql = "INSERT INTO " . _M2F_PATTERN_MATCH_TABLE_ . " 
							(`pattern_match`,`pattern_replace`,`regexp`,`modifiers`,`description`,`target`,`internal`) 
							VALUES ('" . $m2f_db->escapeSimple($search) . "','','0','','Imported pattern (remove \'$search\' from message subjects)','Subject','0')";
			$db_result = $m2f_db->query($sql);
			check_db_result($db_result, $sql, __LINE__, __FILE__);
	
			$sql = 'SELECT `pattern_id` from ' . _M2F_PATTERN_MATCH_TABLE_ . ' 
								ORDER BY `pattern_id` DESC LIMIT 1';
			$db_result = $m2f_db->getOne($sql);
			check_db_result($db_result, $sql, __LINE__, __FILE__);
			
			$pattern_id = $db_result ? $db_result: 1;
	
			$sql = 'SELECT `order` from ' . _M2F_DIST_LIST_PATTERNS_TABLE_ . ' 
								WHERE distributionlist_id = ' . $dist_list . '
								ORDER BY `order` DESC LIMIT 1';
			$db_result = $m2f_db->getOne($sql);
			check_db_result($db_result, $sql, __LINE__, __FILE__);
		
			$next_order = $db_result ? $db_result + 1: 1;
		
			$sql = 'INSERT INTO ' . _M2F_DIST_LIST_PATTERNS_TABLE_ . ' 
							(`distributionlist_id`, `pattern_id`, `order`)
							VALUES (\'' . $dist_list . '\', \'' . $pattern_id . '\', \'' . $next_order . '\')';
			$db_result = $m2f_db->getAll($sql);
			check_db_result($db_result, $sql, __LINE__, __FILE__);
		}
	}

 	m2f_log(PEAR_LOG_NOTICE , "Added regexp patterns" , __LINE__ , __FILE__);

	// Update version number
	$sql = "UPDATE " . _M2F_CONFIG_TABLE_ . "
	     		SET config_value = 8
	     		WHERE config_name = '_M2F_DB_VERSION_'";
	$db_result = $m2f_db->query($sql);
	check_db_result($db_result, $sql, __LINE__, __FILE__);
	m2f_log(PEAR_LOG_NOTICE , "Updated DB version to 8" , __LINE__ , __FILE__ );

	return TRUE;
}

?>