<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
// +----------------------------------------------------------------------+
// | PHP version 4                                                        |
// +----------------------------------------------------------------------+
// | Copyright (c) 1997-2004 The PHP Group                                |
// +----------------------------------------------------------------------+
// | This source file is subject to version 3.0 of the PHP license,       |
// | that is bundled with this package in the file LICENSE, and is        |
// | available through the world-wide-web at the following url:           |
// | http://www.php.net/license/3_0.txt.                                  |
// | If you did not receive a copy of the PHP license and are unable to   |
// | obtain it through the world-wide-web, please send a note to          |
// | license@php.net so we can mail you a copy immediately.               |
// +----------------------------------------------------------------------+
// | Authors: Roberto Berto <darkelder.php.net>                           |
// +----------------------------------------------------------------------+
//
// $Id: mbox_m2f.php,v 1.4 2006/04/27 16:00:23 georgeocrawford Exp $


// This class was adapted for m2f use by George - partly to make it more useful, partly to sort out some bugs!

require_once "PEAR.php";

class Mail_Mbox_m2f extends PEAR
{
    function open($file, $max_msgs)
    {
        $this->max_msgs = $max_msgs;
        
        // check if file exists else return pear error
        if (!file_exists($file)) {
            return PEAR::raiseError("Cannot open the mbox file: file doesnt exists.");
        }

        // getting next resource it to set
        $resourceId = sizeof($this->_resources) + 1;

        // setting filename to the resource id
        $this->_resources[$resourceId]["filename"] = $file;

        // opening the file
        $this->_resources[$resourceId]["fresource"] = fopen($file, "r");
        if (!is_resource($this->_resources[$resourceId]["fresource"])) {
            return PEAR::raiseError("Cannot open the mbox file: maybe without permission.");
        }

        return $resourceId;
    }


		function retrieve($resourceId)
		{
			// sanity check
			if (!is_resource($this->_resources[$resourceId]['fresource'])) {
					return PEAR::raiseError("Resource isn't valid.");
			}

			// going to start
			if (@fseek($this->_resources[$resourceId]['fresource'], 0) == -1) {
					return PEAR::raiseError("Cannot read mbox");
			}
			
			$start       = 0;
			$laststart   = 0;
			$hasmessage  = false;
			$numMessages = 0;
			$this->messageLocs = array();
			
			while (($line = fgets($this->_resources[$resourceId]['fresource'])) && ( ($this->max_msgs == 0) || ($numMessages <= $this->max_msgs) )) {
					// if line start with "From ", it is a new message
					if (0 === strncmp($line, 'From ', 5)) {
							$numMessages++;
							$laststart = $start;
						 
							$start = ftell($this->_resources[$resourceId]['fresource']) - strlen($line);

							if ($start > 0) {
								// if $hasmessage is true at this stage, it means we've found a message but it wasn't on the first line - 
								// we have blank or non-mbox lines at the beginning of the file.
								// So we don't record the message yet.
								if ($hasmessage === true) {
									$this->messageLocs[] = array($laststart, $start - 1);
								} else {
									$hasmessage = true;
								}
							} else {
                $hasmessage = true;
							}
					}
			}
			// Must pick up the one remaining message if necessary
			if (($start == 0 && $hasmessage === true) || (($numMessages <= $this->max_msgs) && $start > 0) || ($this->max_msgs == 0) ) {
				$this->messageLocs[] = array($start, ftell($this->_resources[$resourceId]['fresource']));
			}
			
			if ( ($this->max_msgs != 0) && isset($this->messageLocs[$this->max_msgs]) ) unset($this->messageLocs[$this->max_msgs]);
			
			if ($this->messageLocs === array()) return array();
			
			$msgs = array();
			
			foreach ($this->messageLocs as $msgLoc) {
				$bytesStart = $msgLoc[0];
				$bytesEnd = $msgLoc[1];

				// seek to start of message
				fseek($this->_resources[$resourceId]["fresource"], $bytesStart);

				if ($bytesEnd - $bytesStart > 0) {
						// reading and returning message (bytes to read = difference of bytes locations)
						$msgs[] = fread($this->_resources[$resourceId]["fresource"], ($bytesEnd - $bytesStart)) . "\n";
				}
			}
			
			return $msgs;
		}


    function removeProcessedmessages($resourceId)
    {
        // changing umask for security reasons
        $umaskOld   = umask(077);
        // creating temp file
        $ftempname  = tempnam ("/tmp", rand(0, 9));
        // returning to old umask
        umask($umaskOld);

        $ftemp      = fopen($ftempname, "w");
        if ($ftemp == false) {
            return PEAR::raiseError("Cannot create a temp file. Cannot handle this error.");            
        }

				$lastMsg = end($this->messageLocs);
				$lastBytePos = $lastMsg[1];
				
				fseek($this->_resources[$resourceId]['fresource'], $lastBytePos+1);
				
				$toSave = fread($this->_resources[$resourceId]['fresource'], filesize($this->_resources[$resourceId]['filename']));
				fwrite($ftemp, $toSave);
				unset($toSave);

        // closing files
        fclose($this->_resources[$resourceId]["fresource"]);
        fclose($ftemp);

        $filename = $this->_resources[$resourceId]["filename"];
        return $this->_move($resourceId, $ftempname, $filename);
    }

    function _move($resourceId, $ftempname, $filename) 
    {
        // opening ftemp to read
        $ftemp = fopen($ftempname, "r");

        if ($ftemp == false) {
            return PEAR::raiseError("Cannot open temp file.");
        }

        // copy from ftemp to fp
        $fp = @fopen($filename, "w");
        if ($fp == false) {
            return PEAR::raiseError("Cannot write on mbox file.");
        }

        while (feof($ftemp) != true) {
            $strings = fread($ftemp, 4096);
            if (fwrite($fp, $strings, strlen($strings)) === false) {
                return PEAR::raiseError("Cannot write to file.");
            }
        }

        fclose($fp);
        fclose($ftemp);
        unlink($ftempname);

        return true;
    }

}
  
?>